==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/DataLakeConnectorMapArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.DataLakeConnectorMapArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * DataLake connector map route properties
 * @property allowedLatencySecs Allowed latency for transferring data.
 * @property clientId Client Id to use.
 * @property maxMessagesPerBatch Maximum messages to send per Batch.
 * @property messagePayloadType Message payload type.
 * @property mqttSourceTopic Mqtt source topic.
 * @property qos Quality of Service.
 * @property table Delta table properties to use.
 */
public data class DataLakeConnectorMapArgs(
    public val allowedLatencySecs: Output<Int>,
    public val clientId: Output<String>,
    public val maxMessagesPerBatch: Output<Double>,
    public val messagePayloadType: Output<String>,
    public val mqttSourceTopic: Output<String>,
    public val qos: Output<Int>? = null,
    public val table: Output<DeltaTableArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.DataLakeConnectorMapArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.DataLakeConnectorMapArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.DataLakeConnectorMapArgs.builder()
            .allowedLatencySecs(allowedLatencySecs.applyValue({ args0 -> args0 }))
            .clientId(clientId.applyValue({ args0 -> args0 }))
            .maxMessagesPerBatch(maxMessagesPerBatch.applyValue({ args0 -> args0 }))
            .messagePayloadType(messagePayloadType.applyValue({ args0 -> args0 }))
            .mqttSourceTopic(mqttSourceTopic.applyValue({ args0 -> args0 }))
            .qos(qos?.applyValue({ args0 -> args0 }))
            .table(table.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [DataLakeConnectorMapArgs].
 */
@PulumiTagMarker
public class DataLakeConnectorMapArgsBuilder internal constructor() {
    private var allowedLatencySecs: Output<Int>? = null

    private var clientId: Output<String>? = null

    private var maxMessagesPerBatch: Output<Double>? = null

    private var messagePayloadType: Output<String>? = null

    private var mqttSourceTopic: Output<String>? = null

    private var qos: Output<Int>? = null

    private var table: Output<DeltaTableArgs>? = null

    /**
     * @param value Allowed latency for transferring data.
     */
    @JvmName("xgjdocpbelkcaari")
    public suspend fun allowedLatencySecs(`value`: Output<Int>) {
        this.allowedLatencySecs = value
    }

    /**
     * @param value Client Id to use.
     */
    @JvmName("ggguhnksheigqguj")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value Maximum messages to send per Batch.
     */
    @JvmName("osvbklqtxcbrweyf")
    public suspend fun maxMessagesPerBatch(`value`: Output<Double>) {
        this.maxMessagesPerBatch = value
    }

    /**
     * @param value Message payload type.
     */
    @JvmName("dsaqgstcbhtmhkkb")
    public suspend fun messagePayloadType(`value`: Output<String>) {
        this.messagePayloadType = value
    }

    /**
     * @param value Mqtt source topic.
     */
    @JvmName("tgiqluqaegvbutds")
    public suspend fun mqttSourceTopic(`value`: Output<String>) {
        this.mqttSourceTopic = value
    }

    /**
     * @param value Quality of Service.
     */
    @JvmName("swsjbpcwyqipvpnx")
    public suspend fun qos(`value`: Output<Int>) {
        this.qos = value
    }

    /**
     * @param value Delta table properties to use.
     */
    @JvmName("wmnueacvpanamkxh")
    public suspend fun table(`value`: Output<DeltaTableArgs>) {
        this.table = value
    }

    /**
     * @param value Allowed latency for transferring data.
     */
    @JvmName("qnlvcxpmssmrocbq")
    public suspend fun allowedLatencySecs(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedLatencySecs = mapped
    }

    /**
     * @param value Client Id to use.
     */
    @JvmName("ehvwttguthtcybey")
    public suspend fun clientId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value Maximum messages to send per Batch.
     */
    @JvmName("uaxqysbsvyeqgyjs")
    public suspend fun maxMessagesPerBatch(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.maxMessagesPerBatch = mapped
    }

    /**
     * @param value Message payload type.
     */
    @JvmName("qoanbrvteshwoggk")
    public suspend fun messagePayloadType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.messagePayloadType = mapped
    }

    /**
     * @param value Mqtt source topic.
     */
    @JvmName("cwnjeeaxcykafwmj")
    public suspend fun mqttSourceTopic(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mqttSourceTopic = mapped
    }

    /**
     * @param value Quality of Service.
     */
    @JvmName("ysecqygcupjrkgrt")
    public suspend fun qos(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.qos = mapped
    }

    /**
     * @param value Delta table properties to use.
     */
    @JvmName("enumyoonewxcuwgj")
    public suspend fun table(`value`: DeltaTableArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.table = mapped
    }

    /**
     * @param argument Delta table properties to use.
     */
    @JvmName("njfgbfmxtldmcnun")
    public suspend fun table(argument: suspend DeltaTableArgsBuilder.() -> Unit) {
        val toBeMapped = DeltaTableArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.table = mapped
    }

    internal fun build(): DataLakeConnectorMapArgs = DataLakeConnectorMapArgs(
        allowedLatencySecs = allowedLatencySecs ?: throw PulumiNullFieldException("allowedLatencySecs"),
        clientId = clientId ?: throw PulumiNullFieldException("clientId"),
        maxMessagesPerBatch = maxMessagesPerBatch ?: throw PulumiNullFieldException("maxMessagesPerBatch"),
        messagePayloadType = messagePayloadType ?: throw PulumiNullFieldException("messagePayloadType"),
        mqttSourceTopic = mqttSourceTopic ?: throw PulumiNullFieldException("mqttSourceTopic"),
        qos = qos,
        table = table ?: throw PulumiNullFieldException("table"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/DataLakeConnectorMapArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.DataLakeConnectorMapArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * DataLake connector map route properties
 * @property allowedLatencySecs Allowed latency for transferring data.
 * @property clientId Client Id to use.
 * @property maxMessagesPerBatch Maximum messages to send per Batch.
 * @property messagePayloadType Message payload type.
 * @property mqttSourceTopic Mqtt source topic.
 * @property qos Quality of Service.
 * @property table Delta table properties to use.
 */
public data class DataLakeConnectorMapArgs(
    public val allowedLatencySecs: Output<Int>,
    public val clientId: Output<String>,
    public val maxMessagesPerBatch: Output<Double>,
    public val messagePayloadType: Output<String>,
    public val mqttSourceTopic: Output<String>,
    public val qos: Output<Int>? = null,
    public val table: Output<DeltaTableArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.DataLakeConnectorMapArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.DataLakeConnectorMapArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.DataLakeConnectorMapArgs.builder()
            .allowedLatencySecs(allowedLatencySecs.applyValue({ args0 -> args0 }))
            .clientId(clientId.applyValue({ args0 -> args0 }))
            .maxMessagesPerBatch(maxMessagesPerBatch.applyValue({ args0 -> args0 }))
            .messagePayloadType(messagePayloadType.applyValue({ args0 -> args0 }))
            .mqttSourceTopic(mqttSourceTopic.applyValue({ args0 -> args0 }))
            .qos(qos?.applyValue({ args0 -> args0 }))
            .table(table.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [DataLakeConnectorMapArgs].
 */
@PulumiTagMarker
public class DataLakeConnectorMapArgsBuilder internal constructor() {
    private var allowedLatencySecs: Output<Int>? = null

    private var clientId: Output<String>? = null

    private var maxMessagesPerBatch: Output<Double>? = null

    private var messagePayloadType: Output<String>? = null

    private var mqttSourceTopic: Output<String>? = null

    private var qos: Output<Int>? = null

    private var table: Output<DeltaTableArgs>? = null

    /**
     * @param value Allowed latency for transferring data.
     */
    @JvmName("ofuttgboachqwccx")
    public suspend fun allowedLatencySecs(`value`: Output<Int>) {
        this.allowedLatencySecs = value
    }

    /**
     * @param value Client Id to use.
     */
    @JvmName("oxjwbwpnnmijdkba")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value Maximum messages to send per Batch.
     */
    @JvmName("kajldkaeisgxfoqk")
    public suspend fun maxMessagesPerBatch(`value`: Output<Double>) {
        this.maxMessagesPerBatch = value
    }

    /**
     * @param value Message payload type.
     */
    @JvmName("pnkqsvsxindotugx")
    public suspend fun messagePayloadType(`value`: Output<String>) {
        this.messagePayloadType = value
    }

    /**
     * @param value Mqtt source topic.
     */
    @JvmName("vmrbfowjdrurecjp")
    public suspend fun mqttSourceTopic(`value`: Output<String>) {
        this.mqttSourceTopic = value
    }

    /**
     * @param value Quality of Service.
     */
    @JvmName("agxvxhapbhjlkklt")
    public suspend fun qos(`value`: Output<Int>) {
        this.qos = value
    }

    /**
     * @param value Delta table properties to use.
     */
    @JvmName("vhtkxtvdafomqpfc")
    public suspend fun table(`value`: Output<DeltaTableArgs>) {
        this.table = value
    }

    /**
     * @param value Allowed latency for transferring data.
     */
    @JvmName("htfwvbkykavibnis")
    public suspend fun allowedLatencySecs(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedLatencySecs = mapped
    }

    /**
     * @param value Client Id to use.
     */
    @JvmName("imdgqruscxrvwwqd")
    public suspend fun clientId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value Maximum messages to send per Batch.
     */
    @JvmName("oqogtojecubnxoyv")
    public suspend fun maxMessagesPerBatch(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.maxMessagesPerBatch = mapped
    }

    /**
     * @param value Message payload type.
     */
    @JvmName("lnfktomjbqovepkx")
    public suspend fun messagePayloadType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.messagePayloadType = mapped
    }

    /**
     * @param value Mqtt source topic.
     */
    @JvmName("rovewbnhiiyxjoci")
    public suspend fun mqttSourceTopic(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mqttSourceTopic = mapped
    }

    /**
     * @param value Quality of Service.
     */
    @JvmName("ucancxkppkodgrkx")
    public suspend fun qos(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.qos = mapped
    }

    /**
     * @param value Delta table properties to use.
     */
    @JvmName("vpdoeaggxsccikcp")
    public suspend fun table(`value`: DeltaTableArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.table = mapped
    }

    /**
     * @param argument Delta table properties to use.
     */
    @JvmName("ucdkirtfsiqvwgpj")
    public suspend fun table(argument: suspend DeltaTableArgsBuilder.() -> Unit) {
        val toBeMapped = DeltaTableArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.table = mapped
    }

    internal fun build(): DataLakeConnectorMapArgs = DataLakeConnectorMapArgs(
        allowedLatencySecs = allowedLatencySecs ?: throw PulumiNullFieldException("allowedLatencySecs"),
        clientId = clientId ?: throw PulumiNullFieldException("clientId"),
        maxMessagesPerBatch = maxMessagesPerBatch ?: throw PulumiNullFieldException("maxMessagesPerBatch"),
        messagePayloadType = messagePayloadType ?: throw PulumiNullFieldException("messagePayloadType"),
        mqttSourceTopic = mqttSourceTopic ?: throw PulumiNullFieldException("mqttSourceTopic"),
        qos = qos,
        table = table ?: throw PulumiNullFieldException("table"),
    )
}
